==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/DistributedNodesInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.DistributedNodesInfoArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * This is used to represent the various nodes of the distributed container.
 * @property nodeName Name of the node under a distributed container.
 * @property sourceResourceId ARM resource id of the node
 * @property status Status of this Node.
 * Failed | Succeeded
 */
public data class DistributedNodesInfoArgs(
    public val nodeName: Output<String>? = null,
    public val sourceResourceId: Output<String>? = null,
    public val status: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.DistributedNodesInfoArgs> {
    override fun toJava(): com.pulumi.azurenative.recoveryservices.inputs.DistributedNodesInfoArgs =
        com.pulumi.azurenative.recoveryservices.inputs.DistributedNodesInfoArgs.builder()
            .nodeName(nodeName?.applyValue({ args0 -> args0 }))
            .sourceResourceId(sourceResourceId?.applyValue({ args0 -> args0 }))
            .status(status?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DistributedNodesInfoArgs].
 */
@PulumiTagMarker
public class DistributedNodesInfoArgsBuilder internal constructor() {
    private var nodeName: Output<String>? = null

    private var sourceResourceId: Output<String>? = null

    private var status: Output<String>? = null

    /**
     * @param value Name of the node under a distributed container.
     */
    @JvmName("xgvjkhbvlcdoktud")
    public suspend fun nodeName(`value`: Output<String>) {
        this.nodeName = value
    }

    /**
     * @param value ARM resource id of the node
     */
    @JvmName("eripidbttojfxknd")
    public suspend fun sourceResourceId(`value`: Output<String>) {
        this.sourceResourceId = value
    }

    /**
     * @param value Status of this Node.
     * Failed | Succeeded
     */
    @JvmName("fsnjtoywepnhblof")
    public suspend fun status(`value`: Output<String>) {
        this.status = value
    }

    /**
     * @param value Name of the node under a distributed container.
     */
    @JvmName("oprotcqrdgmklvah")
    public suspend fun nodeName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.nodeName = mapped
    }

    /**
     * @param value ARM resource id of the node
     */
    @JvmName("wvnghcdevtjxnqhl")
    public suspend fun sourceResourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sourceResourceId = mapped
    }

    /**
     * @param value Status of this Node.
     * Failed | Succeeded
     */
    @JvmName("icvtvmkolqkvggog")
    public suspend fun status(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.status = mapped
    }

    internal fun build(): DistributedNodesInfoArgs = DistributedNodesInfoArgs(
        nodeName = nodeName,
        sourceResourceId = sourceResourceId,
        status = status,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/recoveryservices/kotlin/inputs/DistributedNodesInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.recoveryservices.kotlin.inputs

import com.pulumi.azurenative.recoveryservices.inputs.DistributedNodesInfoArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * This is used to represent the various nodes of the distributed container.
 * @property nodeName Name of the node under a distributed container.
 * @property sourceResourceId ARM resource id of the node
 * @property status Status of this Node.
 * Failed | Succeeded
 */
public data class DistributedNodesInfoArgs(
    public val nodeName: Output<String>? = null,
    public val sourceResourceId: Output<String>? = null,
    public val status: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.recoveryservices.inputs.DistributedNodesInfoArgs> {
    override fun toJava(): com.pulumi.azurenative.recoveryservices.inputs.DistributedNodesInfoArgs =
        com.pulumi.azurenative.recoveryservices.inputs.DistributedNodesInfoArgs.builder()
            .nodeName(nodeName?.applyValue({ args0 -> args0 }))
            .sourceResourceId(sourceResourceId?.applyValue({ args0 -> args0 }))
            .status(status?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DistributedNodesInfoArgs].
 */
@PulumiTagMarker
public class DistributedNodesInfoArgsBuilder internal constructor() {
    private var nodeName: Output<String>? = null

    private var sourceResourceId: Output<String>? = null

    private var status: Output<String>? = null

    /**
     * @param value Name of the node under a distributed container.
     */
    @JvmName("ocyxocrspkqfoosl")
    public suspend fun nodeName(`value`: Output<String>) {
        this.nodeName = value
    }

    /**
     * @param value ARM resource id of the node
     */
    @JvmName("tehmxevmruxfwtmi")
    public suspend fun sourceResourceId(`value`: Output<String>) {
        this.sourceResourceId = value
    }

    /**
     * @param value Status of this Node.
     * Failed | Succeeded
     */
    @JvmName("ewlsffuorfmfaogg")
    public suspend fun status(`value`: Output<String>) {
        this.status = value
    }

    /**
     * @param value Name of the node under a distributed container.
     */
    @JvmName("kcwruujjtfsxuybl")
    public suspend fun nodeName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.nodeName = mapped
    }

    /**
     * @param value ARM resource id of the node
     */
    @JvmName("qqyfrahmxjmjhelm")
    public suspend fun sourceResourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sourceResourceId = mapped
    }

    /**
     * @param value Status of this Node.
     * Failed | Succeeded
     */
    @JvmName("dlkxwhphreyqreqn")
    public suspend fun status(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.status = mapped
    }

    internal fun build(): DistributedNodesInfoArgs = DistributedNodesInfoArgs(
        nodeName = nodeName,
        sourceResourceId = sourceResourceId,
        status = status,
    )
}
